Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(823)

Unified Diff: include/v8.h

Issue 1019793008: Deprecate IdleNotification() (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: updates Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 522d8325fad8ad1d2377e78b94f2ea244a6b57d4..19ba8e71b048b7013dae8ad40c9ebb5d739d2bef 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -5418,8 +5418,9 @@ class V8_EXPORT Isolate {
*
* This should only be used for testing purposes and not to enforce a garbage
* collection schedule. It has strong negative impact on the garbage
* collection performance. Use IdleNotification() or LowMemoryNotification()
* instead to influence the garbage collection schedule.
*/
void RequestGarbageCollectionForTesting(GarbageCollectionType type);
@@ -5501,24 +5502,21 @@ class V8_EXPORT Isolate {
* Optional notification that the embedder is idle.
* V8 uses the notification to perform garbage collection.
* This call can be used repeatedly if the embedder remains idle.
* Returns true if the embedder should stop calling IdleNotification
* until real work has been done. This indicates that V8 has done
* as much cleanup as it will be able to do.
*
- * The idle_time_in_ms argument specifies the time V8 has to perform
- * garbage collection. There is no guarantee that the actual work will be
- * done within the time limit. This variant is deprecated and will be removed
- * in the future.
- *
* The deadline_in_seconds argument specifies the deadline V8 has to finish
* garbage collection work. deadline_in_seconds is compared with
* MonotonicallyIncreasingTime() and should be based on the same timebase as
* that function. There is no guarantee that the actual work will be done
* within the time limit.
*/
- bool IdleNotification(int idle_time_in_ms);
bool IdleNotificationDeadline(double deadline_in_seconds);
+ V8_DEPRECATE_SOON("use IdleNotificationDeadline()",
+ bool IdleNotification(int idle_time_in_ms));
+
/**
* Optional notification that the system is running low on memory.
* V8 uses these notifications to attempt to free memory.
@@ -5418,8 +5418,9 @@ class V8_EXPORT Isolate {
* This should only be used for testing purposes and not to enforce a garbage
* collection schedule. It has strong negative impact on the garbage
- * collection performance. Use IdleNotification() or LowMemoryNotification()
- * instead to influence the garbage collection schedule.
+ * collection performance. Use IdleNotificationDeadline() or
+ * LowMemoryNotification() instead to influence the garbage collection
+ * schedule.
*/
void RequestGarbageCollectionForTesting(GarbageCollectionType type);
@@ -5501,24 +5502,21 @@ class V8_EXPORT Isolate {
* V8 uses the notification to perform garbage collection.
* This call can be used repeatedly if the embedder remains idle.
- * Returns true if the embedder should stop calling IdleNotification
+ * Returns true if the embedder should stop calling IdleNotificationDeadline
* until real work has been done. This indicates that V8 has done
* as much cleanup as it will be able to do.
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698